==> zbxe.beta.0.2.1.tgz: zbxe/modules/document/lang/en.lang.php <==
<?php
    /**
     * @file   modules/document/lang/en.lang.php
     * @author zero <zero@nzeo.com>
     * @brief  Document module's basic language pack
     **/

    $lang->document_list = 'Document list';
    $lang->thumbnail_type = 'Thumbnail Type';
    $lang->thumbnail_crop = 'Crop';
    $lang->thumbnail_ratio = 'Ratio';
    $lang->cmd_delete_all_thumbnail = 'Delete all thumbnails';
    $lang->move_target_module = "Target module for changing position";

	$lang->cmd_toggle_checked_document = '선택항목 반전';
    $lang->cmd_delete_checked_document = 'Delete selected';

    $lang->msg_cart_is_null = 'Select the articles you wish to delete';
    $lang->msg_category_not_moved = 'Unabled to move';
    $lang->msg_is_secret = 'This article is secret';
    $lang->msg_checked_document_is_deleted = 'Total of %d articles has been deleted';

    // Search targets in admin page
        $lang->search_target_list = array(
        'title' => 'Subject',
        'content' => 'Content',
        'user_id' => 'User ID',
        'member_srl' => 'Member No.',
        'user_name' => 'Content',
        'nick_name' => 'Content',
        'email_address' => 'Email',
        'homepage' => 'Homepage',
        'is_notice' => 'Notice',
        'is_secret' => 'Secret',
        'tags' => 'Tag',
        'readed_count' => 'Number of Views (Above)',
        'voted_count' => 'Number of Votes (Above)',
        'comment_count ' => 'Number of Comments (Above)',
        'trackback_count ' => 'Number of trackbacks (Above)',
        'uploaded_count ' => 'Number of Attachments (Above)',
        'regdate' => 'Date',
        'last_update' => 'Last Revised',
        'ipaddress' => 'IP Address',
    );
?>

==> zbxe.beta.0.2.4.tgz: zbxe/modules/document/lang/en.lang.php <==
<?php
    /**
     * @file   modules/document/lang/en.lang.php
     * @author zero <zero@nzeo.com>
     * @brief  Document module's basic language pack
     **/

    $lang->document_list = 'Document list';
    $lang->thumbnail_type = 'Thumbnail Type';
    $lang->thumbnail_crop = 'Crop';
    $lang->thumbnail_ratio = 'Ratio';
    $lang->cmd_delete_all_thumbnail = 'Delete all thumbnails';
    $lang->move_target_module = "Target module for changing position";
    $lang->title_bold = '제목 굵게';
    $lang->title_color = '제목 색깔';

	$lang->cmd_toggle_checked_document = 'Reverse selected items';
    $lang->cmd_delete_checked_document = 'Delete selected';
    $lang->cmd_document_do = '이 게시물을..';

    $lang->msg_cart_is_null = 'Select the articles you wish to delete';
    $lang->msg_category_not_moved = 'Unabled to move';
    $lang->msg_is_secret = 'This article is secret';
    $lang->msg_checked_document_is_deleted = 'Total of %d articles has been deleted';

    // Search targets in admin page
        $lang->search_target_list = array(
        'title' => 'Subject',
        'content' => 'Content',
        'user_id' => 'User ID',
        'member_srl' => 'Member No.',
        'user_name' => 'Content',
        'nick_name' => 'Content',
        'email_address' => 'Email',
        'homepage' => 'Homepage',
        'is_notice' => 'Notice',
        'is_secret' => 'Secret',
        'tags' => 'Tag',
        'readed_count' => 'Number of Views (Above)',
        'voted_count' => 'Number of Votes (Above)',
        'comment_count ' => 'Number of Comments (Above)',
        'trackback_count ' => 'Number of trackbacks (Above)',
        'uploaded_count ' => 'Number of Attachments (Above)',
        'regdate' => 'Date',
        'last_update' => 'Last Revised',
        'ipaddress' => 'IP Address',
    );
?>
